@@ -15,33 +15,31 @@ test_that("hy_daily_flows accepts single and multiple station arguments", {
 })
 
 
-test_that("hy_daily_flows accepts single and multiple province arguments",
-          {
-            expect_true(nrow(
-              hy_daily_flows(
-                prov_terr_state_loc = "BC",
-                hydat_path = hy_test_db()
-              )
-            ) >= 1)
-            expect_true(nrow(
-              hy_daily_flows(
-                prov_terr_state_loc = c("BC", "YT"),
-                hydat_path = hy_test_db()
-              )
-            ) >= 1)
-          })
+test_that("hy_daily_flows accepts single and multiple province arguments", {
+  expect_true(nrow(
+    hy_daily_flows(
+      prov_terr_state_loc = "BC",
+      hydat_path = hy_test_db()
+    )
+  ) >= 1)
+  expect_true(nrow(
+    hy_daily_flows(
+      prov_terr_state_loc = c("BC", "YT"),
+      hydat_path = hy_test_db()
+    )
+  ) >= 1)
+})
 
-test_that("hy_daily_flows produces an error when a province is not specified correctly",
-          {
-            expect_error(hy_daily_flows(
-              prov_terr_state_loc = "BCD",
-              hydat_path = hy_test_db()
-            ))
-            expect_error(hy_daily_flows(
-              prov_terr_state_loc = c("YT", "BCD"),
-              hydat_path = hy_test_db()
-            ))
-          })
+test_that("hy_daily_flows produces an error when a province is not specified correctly", {
+  expect_error(hy_daily_flows(
+    prov_terr_state_loc = "BCD",
+    hydat_path = hy_test_db()
+  ))
+  expect_error(hy_daily_flows(
+    prov_terr_state_loc = c("YT", "BCD"),
+    hydat_path = hy_test_db()
+  ))
+})
 
 ## Too much data
 # test_that("hy_daily_flows gather data when no arguments are supplied",{
@@ -59,12 +57,12 @@ test_that("hy_daily_flows respects Date specification", {
   expect_identical(c(min(temp_df$Date), max(temp_df$Date)), as.Date(date_vector))
 })
 
-test_that("functions that accept a date argument return data when specifying only the start date or end date",{
+test_that("functions that accept a date argument return data when specifying only the start date or end date", {
   date_string <- "1961-01-01"
-  
+
   open_date_start <- hy_daily_flows(station_number = "08MF005", hydat_path = hy_test_db(), start_date = date_string)
   expect_identical(min(open_date_start$Date), as.Date(date_string))
-  
+
   open_date_end <- hy_daily_flows(station_number = "08MF005", hydat_path = hy_test_db(), end_date = date_string)
   expect_identical(max(open_date_end$Date), as.Date(date_string))
 })
